@@ -24,7 +24,44 @@
 ;; Boston, MA  02110-1301,  USA       gnu@gnu.org
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+
+(define-module (gnucash qif-import qif-dialog-utils))
+
+(eval-when (compile load eval expand)
+  (load-extension "libgnc-gnome" "scm_init_sw_gnome_module"))
+
+(use-modules (srfi srfi-1))
+(use-modules (sw_gnome))
+(use-modules (gnucash core-utils))
+(use-modules (gnucash engine))
 (use-modules (gnucash string))
+(use-modules (gnucash app-utils))
+(use-modules (gnucash qif-import qif-objects))
+(use-modules (gnucash qif-import qif-guess-map))
+
+(export default-capital-return-acct)
+(export default-cglong-acct)
+(export default-cgmid-acct)
+(export default-cgshort-acct)
+(export default-commission-acct)
+(export default-dividend-acct)
+(export default-equity-account)
+(export default-equity-holding)
+(export default-interest-acct)
+(export default-margin-interest-acct)
+(export default-stock-acct)
+(export default-unspec-acct)
+(export qif-dialog:make-account-display)
+(export qif-dialog:make-category-display)
+(export qif-dialog:make-memo-display)
+(export qif-dialog:qif-file-loaded?)
+(export qif-dialog:unload-qif-file)
+(export qif-import:any-new-accts?)
+(export qif-import:get-account-name)
+(export qif-import:update-security-hash)
+(export qif-import:fix-from-acct)
+(export qif-import:get-all-accts)
+(export qif-import:refresh-match-selection)
 
 (define (default-stock-acct brokerage security)
   (string-append brokerage (gnc-get-account-separator-string) security))
@@ -412,8 +449,8 @@
     (set! retval
           (sort retval
                 (lambda (a b)
-                  (string<? (qif-map-entry:qif-name a)
-                            (qif-map-entry:qif-name b)))))
+                  (gnc:string-locale<? (qif-map-entry:qif-name a)
+                                       (qif-map-entry:qif-name b)))))
     retval))
 
 
@@ -532,8 +569,8 @@
     ;; sort by qif account name
     (set! retval (sort retval
                        (lambda (a b)
-                         (string<? (qif-map-entry:qif-name a)
-                                   (qif-map-entry:qif-name b)))))
+                         (gnc:string-locale<? (qif-map-entry:qif-name a)
+                                              (qif-map-entry:qif-name b)))))
     retval))
 
 ;; this one's like the other display builders, it just looks at the
@@ -624,8 +661,8 @@
     ;; sort by qif memo/payee name
     (set! retval (sort retval
                        (lambda (a b)
-                         (string<? (qif-map-entry:qif-name a)
-                                   (qif-map-entry:qif-name b)))))
+                         (gnc:string-locale<? (qif-map-entry:qif-name a)
+                                              (qif-map-entry:qif-name b)))))
     retval))
 
 
@@ -687,6 +724,11 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 (define (qif-dialog:default-namespace qif-symbol qif-type prefs)
 
+  (define (currency_ns? ns)
+    (or (string=? (GNC-COMMODITY-NS-CURRENCY) ns)
+        (string=? (GNC-COMMODITY-NS-LEGACY) ns)
+        (string=? (GNC-COMMODITY-NS-ISO4217) ns)))
+
   ;; Guess a namespace based on the symbol alone.
   (define (guess-by-symbol s)
     (if (string? s)
@@ -699,58 +741,20 @@
                           ;; compatible with the QIF type?
                           (and (string=? s (caddr elt))
                                (not (and (string? qif-type)
-                                         (string=? GNC_COMMODITY_NS_MUTUAL
-                                                   (cadr elt))
+                                         (not (currency_ns? (cadr elt))
                                          (or (string-ci=? qif-type "stock")
-                                             (string-ci=? qif-type "etf"))))))
+                                             (string-ci=? qif-type "etf")
+                                             (string-ci=? qif-type "mutual fund")
+                                             (string-ci=? qif-type "index")
+)))))
                         prefs)
-                   #f)))
-        (cond
-          ;; If a preferences match was found, use its namespace.
-          (pref-match
-           (cadr pref-match))
+                   #f))))
+        ;; If a preferences match was found, use its namespace.
+        (if pref-match (cadr pref-match)))
+      ;; There's no symbol. Use the built-in default.
+      (GNC-COMMODITY-NS-NONCURRENCY)))
 
-          ;; Guess NYSE for symbols of 1-3 characters.
-          ((< l 4)
-           GNC_COMMODITY_NS_NYSE)
-
-          ;; Guess NYSE for symbols of 1-3 characters
-          ;; followed by a dot and 1-2 characters.
-          ((and d
-                (< l 7)
-                (< 0 d 4)
-                (<= 2 (- l d) 3))
-           GNC_COMMODITY_NS_NYSE)
-
-          ;; Guess NASDAQ for symbols of 4 characters.
-          ((= l 4)
-           GNC_COMMODITY_NS_NASDAQ)
-
-          ;; Otherwise it's probably a fund.
-          (else
-           GNC_COMMODITY_NS_MUTUAL)))
-      ;; There's no symbol. Default to a fund.
-      GNC_COMMODITY_NS_MUTUAL))
-
-  ;; Was a QIF type given?
-  (if (string? qif-type)
-     ;; Yes. We might be able to definitely determine the namespace.
-     (cond
-       ;; Mutual fund
-       ((string-ci=? qif-type "mutual fund")
-        GNC_COMMODITY_NS_MUTUAL)
-
-       ;; Index
-       ((string-ci=? qif-type "index")
-        ;; This QIF type must be wrong; indexes aren't tradable!
-        GNC_COMMODITY_NS_MUTUAL)
-
-       (else
-        (guess-by-symbol qif-symbol)))
-
-     ;; No QIF type was given, so guess a
-     ;; default namespace by symbol alone.
-     (guess-by-symbol qif-symbol)))
+  (guess-by-symbol qif-symbol))
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -826,7 +830,7 @@
      #f acct-hash)
 
     (if (not (null? names))
-        (sort names string<?)
+        (sort names gnc:string-locale<?)
         #f)))
 
 ;; this is used within the dialog to get a list of all the new
@@ -867,7 +871,7 @@
                           (loop (car tree-left) (cdr tree-left))
                           (set! newtree (cons (cvt-to-tree path new?)
                                               newtree))))))
-              (sort newtree (lambda (a b) (string<? (car a) (car b))))))))
+              (sort newtree (lambda (a b) (gnc:string-locale<? (car a) (car b))))))))
 
 
   (let ((accts '())
