@@ -97,6 +97,7 @@
 (export gnc:select-assoc-account-balance)
 (export gnc:get-assoc-account-balances-total)
 (export gnc:multiline-to-html-text)
+(export gnc:payment-txn->payment-info)
 (export make-file-url)
 (export gnc:strify)
 (export gnc:pk)
@@ -939,14 +940,12 @@ query instead.")
 ;;
 ;; Returns a gnc-numeric value
 (define (gnc:budget-account-get-rolledup-net budget account start-period end-period)
-  (let* ((start (or start-period 0))
-         (end (or end-period (gnc-budget-get-num-periods budget)))
-         (numperiods (- end start -1)))
-  (apply +
-         (map
-          (lambda (period)
-            (gnc:get-account-period-rolledup-budget-value budget account period))
-          (iota numperiods start 1)))))
+  (define end (or end-period (1- (gnc-budget-get-num-periods budget))))
+  (let lp ((period (or start-period 0)) (sum 0))
+    (cond
+     ((> period end) sum)
+     (else (lp (1+ period) (+ sum (gnc:get-account-period-rolledup-budget-value
+                                   budget account period)))))))
 
 ;; ***************************************************************************
 ;; The following 3 functions belong together
@@ -983,6 +982,57 @@ query instead.")
 ;; ***************************************************************************
 ;; Business Functions
 
+(define (sign-equal? a b) (or (= 0 a b) (< 0 (* a b))))
+(define (not-APAR? s)
+  (not (xaccAccountIsAPARType (xaccAccountGetType (xaccSplitGetAccount s)))))
+;; analyse a payment transaction and return a 3-element vector:
+;; (vector invoices opposing-splits overpayment)
+;;
+;; invoices: a list of (cons invoice inv-APAR-split)
+;; opposing-splits: a list of (list pmt-APAR-split partial-amount derived?)
+;;                 partial-amount is a number, derived? is #true if the partial
+;;                 amount does not match the transaction amount
+;; overpayment: a number indicating overpayment amount
+(define (gnc:payment-txn->payment-info txn)
+  (let lp ((splits (xaccTransGetSplitList txn))
+           (invoices '())
+           (overpayment 0)
+           (opposing-splits '()))
+    (match splits
+      (() (vector invoices opposing-splits overpayment))
+      (((? not-APAR? split) . rest)
+       (lp rest invoices (+ overpayment (xaccSplitGetAmount split))
+           opposing-splits))
+      ((split . rest)
+       (let* ((lot (xaccSplitGetLot split))
+              (lot-all-splits (gnc-lot-get-split-list lot)))
+         (define split=? (cut equal? <> split))
+         (match (gncInvoiceGetInvoiceFromLot lot)
+           (() (let lp1 ((lot-splits lot-all-splits)
+                         (overpayment overpayment)
+                         (opposing-splits opposing-splits))
+                 (match lot-splits
+                   (() (lp rest invoices overpayment opposing-splits))
+                   (((? split=?) . tail) (lp1 tail overpayment opposing-splits))
+                   ((s . tail)
+                    (let* ((lot-bal (gnc-lot-get-balance lot))
+                           (lot-bal (if (sign-equal? lot-bal (xaccSplitGetAmount s))
+                                        0 lot-bal))
+                           (derived? (not (zero? lot-bal)))
+                           (partial-amount
+                            (fold
+                             (lambda (a b)
+                               (if (equal? s a) b (+ b (xaccSplitGetAmount a))))
+                             (- lot-bal) lot-all-splits)))
+                      (lp1 tail (+ overpayment partial-amount)
+                           (cons (list s partial-amount derived?)
+                                 opposing-splits)))))))
+           (inv
+            (lp rest
+                (cons (cons inv split) invoices)
+                (+ overpayment (xaccSplitGetAmount split))
+                opposing-splits))))))))
+
 ;; create a stepped list, then add a date in the infinite future for
 ;; the "current" bucket
 (define (make-extended-interval-list to-date num-buckets)
@@ -1031,23 +1081,18 @@ query instead.")
                 (loop (1+ idx) (cdr bucket-dates))))
           (lp (cdr splits))))
 
-       ;; next split is a payment. analyse its sister APAR splits. any
-       ;; split whose lot has no invoice is an overpayment.
+       ;; next split is a payment. analyze using
+       ;; gnc:payment-txn->payment-info and use its overpayment
        ((eqv? (xaccTransGetTxnType (xaccSplitGetParent (car splits)))
               TXN-TYPE-PAYMENT)
         (let* ((txn (xaccSplitGetParent (car splits)))
-               (splitlist (xaccTransGetAPARAcctSplitList txn #f))
-               (overpayment
-                (fold
-                 (lambda (a b)
-                   (if (null? (gncInvoiceGetInvoiceFromLot (xaccSplitGetLot a)))
-                       (- b (gnc-lot-get-balance (xaccSplitGetLot a)))
-                       b))
-                 0 splitlist)))
+               (payment-info (gnc:payment-txn->payment-info txn))
+               (overpayment (vector-ref payment-info 2)))
+          (define (not-txn? s) (not (equal? txn (xaccSplitGetParent s))))
           (gnc:msg "next " (gnc:strify (car splits))
                    " overpayment " overpayment)
           (addbucket! (1- num-buckets) (if receivable? (- overpayment) overpayment))
-          (lp (cdr splits))))
+          (lp (filter not-txn? splits))))
 
        ;; not invoice/prepayment. regular or payment split.
        (else
