@@ -31,6 +31,7 @@
 (use-modules (gnucash app-utils))
 (use-modules (gnucash report))
 (use-modules (srfi srfi-1))
+(use-modules (ice-9 format))
 
 (define menuname-income (N_ "Income Piechart"))
 (define menuname-expense (N_ "Expense Piechart"))
@@ -67,7 +68,7 @@ balance at a given time"))
 (define optname-price-source (N_ "Price Source"))
 
 (define optname-accounts (N_ "Accounts"))
-(define optname-levels (N_ "Show Accounts until level"))
+(define optname-levels (N_ "Levels of Subaccounts"))
 
 (define optname-fullname (N_ "Show long names"))
 (define optname-show-total (N_ "Show Totals"))
@@ -83,15 +84,12 @@ balance at a given time"))
 ;; The option-generator. The only dependence on the type of piechart
 ;; is the list of account types that the account selection option
 ;; accepts.
-(define (options-generator account-types reverse-balance? do-intervals? depth-based?)
+(define (options-generator account-types do-intervals? depth-based?)
   (let* ((options (gnc:new-options)) 
          (add-option 
           (lambda (new-option)
             (gnc:register-option options new-option))))
 
-    (add-option
-     (gnc:make-internal-option "__report" "reverse-balance?" reverse-balance?))
-
     (if do-intervals?
         (gnc:options-add-date-interval!
          options gnc:pagename-general
@@ -113,21 +111,10 @@ balance at a given time"))
           gnc:pagename-general optname-averaging
           "f" opthelp-averaging
           'None
-          (list (vector 'None
-                        (N_ "No Averaging")
-                        (N_ "Just show the amounts, without any averaging."))
-                (vector 'YearDelta
-                        (N_ "Yearly")
-                        (N_ "Show the average yearly amount during the reporting period."))
-                (vector 'MonthDelta
-                        (N_ "Monthly")
-                        (N_ "Show the average monthly amount during the reporting period."))
-                (vector 'WeekDelta
-                        (N_ "Weekly")
-                        (N_ "Show the average weekly amount during the reporting period."))
-                )
-          ))
-        )
+          (list (vector 'None (N_ "No Averaging"))
+                (vector 'YearDelta (N_ "Yearly"))
+                (vector 'MonthDelta (N_ "Monthly"))
+                (vector 'WeekDelta (N_ "Weekly"))))))
 
     (add-option
      (gnc:make-account-list-option
@@ -148,7 +135,7 @@ balance at a given time"))
     (if depth-based?
       (gnc:options-add-account-levels!
        options gnc:pagename-accounts optname-levels "b"
-       (N_ "Show accounts to this depth and not further.")
+       (N_ "Maximum number of levels in the account tree displayed.")
        2))
 
     (add-option
@@ -209,12 +196,12 @@ balance at a given time"))
   (cond
    ((eq? sort-method 'acct-code)
     (lambda (a b)
-      (string<? (xaccAccountGetCode (cadr a))
-                (xaccAccountGetCode (cadr b)))))
+      (gnc:string-locale<? (xaccAccountGetCode (cadr a))
+                           (xaccAccountGetCode (cadr b)))))
    ((eq? sort-method 'alphabetical)
     (lambda (a b)
-      (string<? (display-name-accounts show-fullname? (cadr a))
-                (display-name-accounts show-fullname? (cadr b)))))
+      (gnc:string-locale<? (display-name-accounts show-fullname? (cadr a))
+                           (display-name-accounts show-fullname? (cadr b)))))
    (else
     (lambda (a b) (> (car a) (car b))))))
 
@@ -223,12 +210,12 @@ balance at a given time"))
   (cond
    ((eq? sort-method 'acct-code)
     (lambda (a b)
-      (string<? (gnc-commodity-get-mnemonic (cadr a))
-                (gnc-commodity-get-mnemonic (cadr b)))))
+      (gnc:string-locale<? (gnc-commodity-get-mnemonic (cadr a))
+                           (gnc-commodity-get-mnemonic (cadr b)))))
    ((eq? sort-method 'alphabetical)
     (lambda (a b)
-      (string<? (display-name-security show-fullname? (cadr a))
-                (display-name-security show-fullname? (cadr b)))))
+      (gnc:string-locale<? (display-name-security show-fullname? (cadr a))
+                           (display-name-security show-fullname? (cadr b)))))
    (else
     (lambda (a b) (> (car a) (car b))))))
 
@@ -315,7 +302,7 @@ balance at a given time"))
 ;; account-types to work on and whether this report works on
 ;; intervals as arguments.
 (define (piechart-renderer report-obj reportname report-guid
-                           account-types do-intervals? depth-based?
+                           account-types do-intervals? depth-based? reverse-balance?
                            display-name sort-comparator get-data)
 
   ;; This is a helper function for looking up option values.
@@ -360,7 +347,6 @@ balance at a given time"))
         (height (get-option gnc:pagename-display optname-plot-height))
         (width (get-option gnc:pagename-display optname-plot-width))
 	(sort-method (get-option gnc:pagename-display optname-sort-method))
-	(reverse-balance? (get-option "__report" "reverse-balance?"))
 
         (document (gnc:make-html-document))
         (chart (gnc:make-html-chart))
@@ -415,8 +401,7 @@ balance at a given time"))
               ((WeekDelta) (string-append report-title " " (G_ "Weekly Average")))
               (else report-title)))
            (combined '())
-           (other-anchor "")
-           (print-info (gnc-commodity-print-info report-currency #t)))
+           (other-anchor ""))
 
       ;; Converts a commodity-collector into one single inexact
       ;; number, depending on the report's currency and the
@@ -462,7 +447,7 @@ balance at a given time"))
 
       (define (fix-signs combined)
         (map (lambda (pair)
-               (if (reverse-balance? (cadr pair))
+               (if reverse-balance?
                    (cons (- (car pair)) (cdr pair))
                    pair))
 	     combined))
@@ -525,7 +510,12 @@ balance at a given time"))
                                                    ((if show-fullname?
                                                         gnc-account-get-full-name
                                                         xaccAccountGetName) acct))))))))
-                               combined))))
+                               combined)))
+                   (scu (gnc-commodity-get-fraction report-currency)))
+
+               (define (round-scu amt)
+                 (gnc-numeric-convert amt scu GNC-HOW-RND-ROUND))
+
                (gnc:html-chart-set-type! chart 'pie)
 
                (gnc:html-chart-set-currency-iso!
@@ -550,13 +540,14 @@ balance at a given time"))
                                     #f ": ~a"
                                     (gnc:monetary->string
                                      (gnc:make-gnc-monetary
-                                      report-currency total))))
+                                      report-currency
+                                      (round-scu total)))))
                                  ""))))
                (gnc:html-chart-set-width! chart width)
                (gnc:html-chart-set-height! chart height)
                (gnc:html-chart-add-data-series! chart
-                                                "Accounts"
-                                                (unzip1 combined)
+                                                (G_ "Accounts")
+                                                (map round-scu (unzip1 combined))
                                                 (gnc:assign-colors (length combined))
                                                 'urls urls)
                (gnc:html-chart-set-axes-display! chart #f)
@@ -575,7 +566,7 @@ balance at a given time"))
                          (gnc:monetary->string
                           (gnc:make-gnc-monetary
                            report-currency
-                           (car series))))
+                           (round-scu (car series)))))
                         "")
                     (if show-percent?
                         (format #f " (~2,1f%)"
@@ -600,8 +591,8 @@ balance at a given time"))
       document)))
 
 (define (build-report!
-          name acct-types income-expense? depth-based? menuname menutip
-          reverse-balance? uuid)
+         name acct-types income-expense? depth-based? reverse-balance?
+         menuname menutip uuid)
   (gnc:define-report
     'version 1
     'name name
@@ -612,12 +603,12 @@ balance at a given time"))
     'menu-name menuname
     'menu-tip menutip
     'options-generator (lambda () (options-generator acct-types
-                                                     reverse-balance?
                                                      income-expense?
                                                      depth-based?))
     'renderer (lambda (report-obj)
                 (piechart-renderer report-obj name uuid
                                    acct-types income-expense? depth-based?
+                                   reverse-balance?
                                    (if depth-based?
                                        display-name-accounts
                                        display-name-security)
@@ -631,17 +622,15 @@ balance at a given time"))
 (build-report!
   reportname-income
   (list ACCT-TYPE-INCOME)
-  #t #t
+  #t #t #t
   menuname-income menutip-income
-  (lambda (x) #t)
   "e1bd09b8a1dd49dd85760db9d82b045c")
 
 (build-report!
   reportname-expense
   (list ACCT-TYPE-EXPENSE)
-  #t #t
+  #t #t #f
   menuname-expense menutip-expense
-  (lambda (x) #f)
   "9bf1892805cb4336be6320fe48ce5446")
 
 (build-report!
@@ -650,9 +639,8 @@ balance at a given time"))
         ACCT-TYPE-SAVINGS ACCT-TYPE-MONEYMRKT
         ACCT-TYPE-RECEIVABLE ACCT-TYPE-STOCK ACCT-TYPE-MUTUAL
         ACCT-TYPE-CURRENCY)
-  #f #t
+  #f #t #f
   menuname-assets menutip-assets
-  (lambda (x) #f)
   "5c7fd8a1fe9a4cd38884ff54214aa88a")
 
 (build-report!
@@ -661,16 +649,14 @@ balance at a given time"))
         ACCT-TYPE-SAVINGS ACCT-TYPE-MONEYMRKT
         ACCT-TYPE-RECEIVABLE ACCT-TYPE-STOCK ACCT-TYPE-MUTUAL
         ACCT-TYPE-CURRENCY)
-  #f #f
+  #f #f #f
   menuname-securities menutip-securities
-  (lambda (x) #f)
   "e9418ff64f2c11e5b61d1c7508d793ed")
 
 (build-report!
   reportname-liabilities
   (list ACCT-TYPE-LIABILITY ACCT-TYPE-PAYABLE ACCT-TYPE-CREDIT
         ACCT-TYPE-CREDITLINE)
-  #f #t
+  #f #t #t
   menuname-liabilities menutip-liabilities
-  (lambda (x) #t)
   "3fe6dce77da24c66bdc8f8efdea7f9ac")
