@@ -34,6 +34,7 @@
 (use-modules (gnucash app-utils))
 (use-modules (gnucash report))
 (use-modules (srfi srfi-1))
+(use-modules (srfi srfi-26))
 
 (define optname-from-date (N_ "Start Date"))
 (define optname-to-date (N_ "End Date"))
@@ -176,7 +177,7 @@
 ;; includes all the relevant Scheme code. The option database passed
 ;; to the function is one created by the options-generator function
 ;; defined above.
-(define (net-renderer report-obj inc-exp? linechart?)
+(define (net-renderer report-obj inc-exp? linechart? export-type)
 
   ;; This is a helper function for looking up option values.
   (define (get-option section name)
@@ -226,13 +227,16 @@
          (chart (gnc:make-html-chart)))
 
     ;; This exchanges the commodity-collector 'c' to one single
-    ;; 'report-currency' according to the exchange-fn. Returns a gnc:monetary
-    (define (collector->monetary c date)
-      (if (not (number? date))
-          (throw 'wrong))
-      (gnc:sum-collector-commodity
-       c report-currency
-       (lambda (a b) (exchange-fn a b date))))
+    ;; 'report-currency' according to the exchange-fn. Returns an
+    ;; amount.
+    (define (collector->report-currency-amount c date)
+      (fold
+       (lambda (mon acc)
+         (+ acc (gnc-numeric-convert
+                 (gnc:gnc-monetary-amount (exchange-fn mon report-currency date))
+                 (gnc-commodity-get-fraction report-currency)
+                 GNC-RND-ROUND)))
+       0 (c 'format gnc:make-gnc-monetary #f)))
 
     ;; gets an account alist balances
     ;; output: (list acc bal0 bal1 bal2 ...)
@@ -247,8 +251,8 @@
                #:nosplit->elt (gnc:make-gnc-monetary comm 0)))))
 
     ;; This calculates the balances for all the 'account-balances' for
-    ;; each element of the list 'dates'. Uses the collector->monetary
-    ;; conversion function above. Returns a list of gnc-monetary.
+    ;; each element of the list 'dates'. Uses the collector->report-currency-amount
+    ;; conversion function above. Returns a list of amounts.
     (define (process-datelist account-balances dates left-col?)
 
       (define accountlist
@@ -286,7 +290,7 @@
             (loop (cdr dates)
                   (cdr acct-balances)
                   (cons
-                   (collector->monetary
+                   (collector->report-currency-amount
                     (if inc-exp?
                         (gnc:collector- (car acct-balances) (cadr acct-balances))
                         (car acct-balances))
@@ -315,7 +319,7 @@
             (subtrahend-balances (process-datelist account-balancelist dates-list #f))
             (dummy (gnc:report-percent-done 80))
 
-            (difference-balances (map gnc:monetary+ minuend-balances subtrahend-balances))
+            (difference-balances (map + minuend-balances subtrahend-balances))
 
             (dates-list (if inc-exp?
                             (list-head dates-list (1- (length dates-list)))
@@ -347,7 +351,7 @@
          (gnc:html-chart-add-data-series!
           chart
           (if inc-exp? (G_ "Income") (G_ "Assets"))
-          (map gnc:gnc-monetary-amount minuend-balances)
+          minuend-balances
           "#0074D9"
           'fill (not linechart?)
           'pointRadius markers
@@ -368,7 +372,7 @@
          (gnc:html-chart-add-data-series!
           chart
           (if inc-exp? (G_ "Expense") (G_ "Liabilities"))
-          (map - (map gnc:gnc-monetary-amount subtrahend-balances))
+          (map - subtrahend-balances)
           "#FF4136"
           'fill (not linechart?)
           'pointRadius markers
@@ -390,17 +394,16 @@
          (gnc:html-chart-add-data-series!
           chart
           (if inc-exp? (G_ "Net Profit") (G_ "Net Worth"))
-          (map gnc:gnc-monetary-amount difference-balances)
+          difference-balances
           "#2ECC40"
           'fill (not linechart?)
           'pointRadius markers
           'borderWidth line-width))
 
        ;; Test for all-zero data here.
-       (if (gnc:not-all-zeros (map gnc:gnc-monetary-amount
-                                   (append minuend-balances
-                                           subtrahend-balances
-                                           difference-balances)))
+       (if (gnc:not-all-zeros (append minuend-balances
+                                      subtrahend-balances
+                                      difference-balances))
            (begin
              (gnc:html-document-add-object! document chart)
              (if show-table?
@@ -424,24 +427,38 @@
                              (list (G_ "Net Profit"))
                              (list (G_ "Net Worth")))
                          '())))
-                   (gnc:html-table-append-column! table date-string-list)
-                   (when show-sep?
-                     (gnc:html-table-append-column! table minuend-balances)
-                     (gnc:html-table-append-column! table subtrahend-balances))
 
-                   (if show-net?
-                       (gnc:html-table-append-column! table difference-balances))
-
-                   ;; set numeric columns to align right
                    (for-each
-                    (lambda (col)
-                      (gnc:html-table-set-col-style!
-                       table col "td"
-                       'attribute (list "class" "number-cell")))
-                    '(1 2 3))
+                    (lambda (date minuend subtrahend difference)
+                      (gnc:html-table-append-row!
+                       table
+                       (cons date
+                             (map
+                              (cut gnc:make-html-table-cell/markup "number-cell" <>)
+                              (map
+                               (cut gnc:make-gnc-monetary report-currency <>)
+                               (append (if show-sep? (list minuend subtrahend) '())
+                                       (if show-net? (list difference) '())))))))
+                    date-string-list
+                    minuend-balances
+                    subtrahend-balances
+                    difference-balances)
 
-                   (gnc:html-document-add-object! document table))
-                 ))
+                   (gnc:html-document-add-object! document table)))
+
+             (cond
+              ((eq? export-type 'csv)
+               (let ((iso-date (qof-date-format-get-string QOF-DATE-FORMAT-ISO)))
+                 (gnc:html-document-set-export-string
+                  document
+                  (gnc:lists->csv
+                   (cons (if inc-exp?
+                             (map G_ '("Date" "Income" "Expense" "Net Profit"))
+                             (map G_ '("Date" "Assets" "Liabilities" "Net Worth")))
+                         (map list
+                              (map (cut gnc-print-time64 <> iso-date) dates-list)
+                              minuend-balances
+                              subtrahend-balances difference-balances))))))))
            (gnc:html-document-add-object!
             document
             (gnc:html-make-empty-data-warning
@@ -453,6 +470,9 @@
       (gnc:html-make-no-account-warning
        report-title (gnc:report-id report-obj))))
 
+    (unless (gnc:html-document-export-string document)
+      (gnc:html-document-set-export-error document (G_ "No exportable data")))
+
     (gnc:report-finished)
     document))
 
@@ -473,7 +493,10 @@
  'report-guid net-worth-barchart-uuid
  'menu-path (list gnc:menuname-asset-liability)
  'options-generator (lambda () (options-generator #f #f))
- 'renderer (lambda (report-obj) (net-renderer report-obj #f #f)))
+ 'renderer (lambda (report-obj) (net-renderer report-obj #f #f #f))
+ 'export-types '(("CSV" . csv))
+ 'export-thunk (lambda (report-obj export-type)
+                 (net-renderer report-obj #f #f export-type)))
 
 (gnc:define-report
  'version 1
@@ -482,7 +505,10 @@
  'menu-name (N_ "Income & Expense Barchart")
  'menu-path (list gnc:menuname-income-expense)
  'options-generator (lambda () (options-generator #t #f))
- 'renderer (lambda (report-obj) (net-renderer report-obj #t #f)))
+ 'renderer (lambda (report-obj) (net-renderer report-obj #t #f #f))
+ 'export-types '(("CSV" . csv))
+ 'export-thunk (lambda (report-obj export-type)
+                 (net-renderer report-obj #t #f export-type)))
 
 (gnc:define-report
  'version 1
@@ -490,7 +516,10 @@
  'report-guid net-worth-linechart-uuid
  'menu-path (list gnc:menuname-asset-liability)
  'options-generator (lambda () (options-generator #f #t))
- 'renderer (lambda (report-obj) (net-renderer report-obj #f #t)))
+ 'renderer (lambda (report-obj) (net-renderer report-obj #f #t #f))
+ 'export-types '(("CSV" . csv))
+ 'export-thunk (lambda (report-obj export-type)
+                 (net-renderer report-obj #f #t export-type)))
 
 ;; Not sure if a line chart makes sense for Income & Expense
 ;; Feel free to uncomment and try it though
@@ -501,4 +530,7 @@
  'menu-name (N_ "Income & Expense Linechart")
  'menu-path (list gnc:menuname-income-expense)
  'options-generator (lambda () (options-generator #t #t))
- 'renderer (lambda (report-obj) (net-renderer report-obj #t #t)))
+ 'renderer (lambda (report-obj) (net-renderer report-obj #t #t #f))
+ 'export-types '(("CSV" . csv))
+ 'export-thunk (lambda (report-obj export-type)
+                 (net-renderer report-obj #t #t export-type)))
